@@ -158,7 +158,7 @@ def call_function(function_name, data):
     """
     logging.debug(f"{data=}")
     url = read_function_url(function_name) + "/"
-    call_url(url, data)
+    return call_url(url, data)
 
 
 def test_function(function_name, data):
